@@ -1,6 +1,6 @@
 #!/usr/bin/python3
 
-"""combine_cov.py: Combine multiple coverage files of samples from CoverM.
+"""combine_cov.py: Combine multiple coverage files of samples.
 
 """
 
@@ -12,7 +12,7 @@ import subprocess
 import pandas as pd
 
 __author__ = "Vijini Mallawaarachchi"
-__copyright__ = "Copyright 2022, Phables Project"
+__copyright__ = "Copyright 2023, Phables Project"
 __license__ = "MIT"
 __type__ = "Support Script"
 __maintainer__ = "Vijini Mallawaarachchi"
