@@ -1,3 +1,4 @@
+import gc
 import glob
 import os
 import pickle
@@ -35,7 +36,12 @@ def read_pair_generator(bam, region_string=None):
     read_dict = defaultdict(lambda: [None, None])
 
     for read in bam.fetch(region=region_string):
-        if read.is_secondary or read.is_supplementary:
+        if (
+            read.is_secondary
+            or read.is_supplementary
+            or not read.is_paired
+            or read.mapping_quality <= 30
+        ):
             continue
         qname = read.query_name
         if qname not in read_dict:
@@ -82,6 +88,57 @@ def get_junction_pe_coverage(bam_path, output):
     return link_counts
 
 
+def get_sub_path_coverage(sub_path_cov, bam_path, output):
+    """
+    Get coverage values of sub paths using long reads
+    """
+
+    if os.path.isfile(f"{output}/sub_path_coverage.pickle"):
+        sub_path_cov = defaultdict(int)
+        with open(f"{output}/sub_path_coverage.pickle", "rb") as handle:
+            sub_path_cov = pickle.load(handle)
+
+    else:
+        bam_files = glob.glob(bam_path + "/*.bam")
+
+        for bam_file in bam_files:
+            unitig_reads = defaultdict(set)
+
+            bam = pysam.AlignmentFile(bam_file, "rb")
+
+            for read in bam:
+                if not read.is_unmapped:  # Only consider mapped reads
+                    query_id = read.query_name
+                    target_id = read.reference_name
+                    unitig_reads[target_id].add(query_id)
+
+            for sub_path in sub_path_cov.keys():
+                if len(sub_path) == 3:
+                    node1 = sub_path[0]
+                    node2 = sub_path[1]
+                    node3 = sub_path[2]
+
+                    intersection_set = unitig_reads[node1].intersection(
+                        unitig_reads[node2], unitig_reads[node3]
+                    )
+                    sub_path_cov[sub_path] += len(intersection_set)
+
+                elif len(sub_path) == 2:
+                    node1 = sub_path[0]
+                    node2 = sub_path[1]
+
+                    intersection_set = unitig_reads[node1].intersection(
+                        unitig_reads[node2]
+                    )
+                    sub_path_cov[sub_path] += len(intersection_set)
+
+            del unitig_reads
+            del bam
+            gc.collect()
+
+    return sub_path_cov
+
+
 def get_graph_spanning_reads(gaf_path, output):
     """
     Get number of reads spanning across a junction
