@@ -1,11 +1,15 @@
 # Class for genome path
 class GenomePath:
-    def __init__(self, id, node_order, node_id_order, path, coverage, length, gc):
+    def __init__(
+        self, id, bubble_case, node_order, node_order_human, node_id_order, path, coverage, length, gc
+    ):
         self.id = id
+        self.bubble_case = bubble_case
         self.path = path
         self.coverage = coverage
         self.length = length
         self.node_order = node_order
+        self.node_order_human = node_order_human
         self.node_id_order = node_id_order
         self.gc = gc
 
