@@ -1,8 +1,12 @@
+import logging
 import os
 import subprocess
 
 FASTA_LINE_LEN = 60
 
+# Create logger
+logger = logging.getLogger("phables 1.3.3")
+
 
 def write_unitigs(nodes, unitig_names, graph_unitigs, filename, output):
     """
@@ -87,10 +91,10 @@ def write_res_genome_info(all_resolved_paths, output):
     """
 
     with open(f"{output}/resolved_genome_info.txt", "w") as myfile:
-        myfile.write(f"Path\tCoverage\tLength\tGC content\tNode order\n")
+        myfile.write(f"Path\tCase\tCoverage\tLength\tGC content\tNode order (gfa link format)\tNode order (human readable)\n")
         for genomic_path in all_resolved_paths:
             myfile.write(
-                f"{genomic_path.id}\t{genomic_path.coverage}\t{genomic_path.length}\t{genomic_path.gc}\t{genomic_path.node_order}\n"
+                f"{genomic_path.id}\t{genomic_path.bubble_case}\t{genomic_path.coverage}\t{genomic_path.length}\t{genomic_path.gc}\t{genomic_path.node_order}\t{genomic_path.node_order_human}\n"
             )
 
     return "resolved_genome_info.txt"
@@ -141,7 +145,23 @@ def write_component_phrog_info(resolved_components, comp_phrogs, output):
     """
 
     with open(f"{output}/component_phrogs.txt", "w") as myfile:
+        myfile.write(f"Phage component\tPHROG\n")
         for comp in resolved_components:
             myfile.write(f"phage_{comp}\t{comp_phrogs[comp]}\n")
 
     return "component_phrogs.txt"
+
+
+def init_files(output):
+    """
+    Initialise files and folders
+    """
+
+    open(f"{output}/resolved_edges.fasta", "a").close()
+    open(f"{output}/resolved_paths.fasta", "a").close()
+    open(f"{output}/resolved_genome_info.txt", "a").close()
+    open(f"{output}/resolved_component_info.txt", "a").close()
+    open(f"{output}/component_phrogs.txt", "a").close()
+
+    if not os.path.isdir(f"{output}/resolved_phages"):
+        subprocess.run(f"mkdir -p {output}/resolved_phages", shell=True)
